@@ -1,7 +1,10 @@
 from abc import abstractmethod
+from typing import TYPE_CHECKING
 
-from ...utils import Table
-from ..interfaces import IQuery
+from ormlambda.common.interfaces import IQuery
+
+if TYPE_CHECKING:
+    from ormlambda import Table
 
 
 class QueryBase[T: Table](IQuery):
