@@ -311,7 +311,13 @@ class IStatements[T, *Ts](ABC):
     @overload
     def select_one[TFlavour](self, selector: Callable[[T, *Ts], tuple], *, by: Optional[Enum] = ..., flavour: Type[TFlavour]) -> TFlavour: ...
     @abstractmethod
-    def select_one[TValue, TFlavour, *Ts](self, selector: Optional[Callable[[T, *Ts], tuple[TValue, *Ts]]] = lambda: None, *, flavour: Type[TFlavour] = ..., by: Optional[Enum] = ...): ...
+    def select_one[TValue, TFlavour, *Ts](
+        self,
+        selector: Optional[Callable[[T, *Ts], tuple[TValue, *Ts]]] = lambda: None,
+        *,
+        flavour: Type[TFlavour] = ...,
+        by: Optional[Enum] = ...,
+    ): ...
 
     # endregion
     # region group_by
@@ -323,6 +329,9 @@ class IStatements[T, *Ts](ABC):
     @abstractmethod
     def _build(self) -> str: ...
 
+    @abstractmethod
+    def alias(self, column: Callable[[T, *Ts], Any], alias: str) -> IStatements[T, *Ts]: ...
+
 
 class IStatements_two_generic[T: Table, *Ts, TRepo](IStatements[T, *Ts]):
     @property
