@@ -48,8 +48,10 @@ MySQL 8.0 does not support year in two-digit format.
 """
 
 from decimal import Decimal
-import datetime
 from typing import Any, Literal
+import datetime
+
+from shapely import Point
 import numpy as np
 
 from .column import Column
@@ -66,8 +68,11 @@ DATE = Literal["DATE", "DATETIME(fsp)", "TIMESTAMP(fsp)", "TIME(fsp)", "YEAR"]
 def transform_py_dtype_into_query_dtype(dtype: Any) -> str:
     # TODOL: must be found a better way to convert python data type into SQL clauses
     # float -> DECIMAL(5,2) is an error
-    dicc: dict[Any, str] = {int: "INTEGER", float: "FLOAT(5,2)", Decimal: "FLOAT", datetime.datetime: "DATETIME", datetime.date: "DATE", bytes: "BLOB", str: "VARCHAR(255)", np.uint64: "BIGINT UNSIGNED"}
+    dicc: dict[Any, str] = {int: "INTEGER", float: "FLOAT(5,2)", Decimal: "FLOAT", datetime.datetime: "DATETIME", datetime.date: "DATE", bytes: "BLOB", bytearray: "BLOB", str: "VARCHAR(255)", np.uint64: "BIGINT UNSIGNED", Point: "Point"}
 
+    res = dicc.get(dtype, None)
+    if res is None:
+        raise ValueError(f"datatype '{dtype}' is not expected.")
     return dicc[dtype]
 
 
